dbinspect_drift library
A Drift adapter for dbinspect_bridge.
Separate from the bridge core on purpose: an application using Nitrite, or sqflite, or Hive should not acquire a Drift dependency to inspect its own database.
Classes
- DriftAdapter
- Inspects a running Drift database.